@@ -386,13 +386,13 @@ class BatchDumpProcessor:
         """Genera resumen de features extraídas"""
         summary = {
             "total_files": len(dataset),
-            "total_features": len([col for col in dataset.columns if col not in ['file_path', 'vacancies']]),
+            "total_features": len([col for col in dataset.columns if col not in ['file_path']]),
             "feature_categories": {},
             "vacancy_stats": {}
         }
         
         # Categorizar features (excluyendo metadata)
-        feature_cols = [col for col in dataset.columns if col not in ['file_path', 'vacancies']]
+        feature_cols = [col for col in dataset.columns if col not in ['file_path']]
         
         coord_features = [col for col in feature_cols if col.startswith('coord')]
         pe_features = [col for col in feature_cols if col.startswith('pe')]
